summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--asn1/atn-cm/packet-atn-cm-template.c2
-rw-r--r--asn1/atn-cpdlc/packet-atn-cpdlc-template.c2
-rw-r--r--asn1/snmp/packet-snmp-template.c2
-rw-r--r--epan/dissectors/packet-artnet.c2
-rw-r--r--epan/dissectors/packet-atn-cm.c2
-rw-r--r--epan/dissectors/packet-atn-cpdlc.c2
-rw-r--r--epan/dissectors/packet-dcerpc-dce122.c2
-rw-r--r--epan/dissectors/packet-dcom.c2
-rw-r--r--epan/dissectors/packet-devicenet.c6
-rw-r--r--epan/dissectors/packet-etsi_card_app_toolkit.c4
-rw-r--r--epan/dissectors/packet-fmp.c2
-rw-r--r--epan/dissectors/packet-gsm_a_common.c2
-rw-r--r--epan/dissectors/packet-gsm_rlcmac.c10
-rw-r--r--epan/dissectors/packet-icep.c2
-rw-r--r--epan/dissectors/packet-lg8979.c2
-rw-r--r--epan/dissectors/packet-mausb.c16
-rw-r--r--epan/dissectors/packet-ncp2222.inc2
-rw-r--r--epan/dissectors/packet-nstrace.c4
-rw-r--r--epan/dissectors/packet-pathport.c2
-rw-r--r--epan/dissectors/packet-pnrp.c2
-rw-r--r--epan/dissectors/packet-s7comm.c4
-rw-r--r--epan/dissectors/packet-sflow.c2
-rw-r--r--epan/dissectors/packet-smb2.c2
-rw-r--r--epan/dissectors/packet-smcr.c4
-rw-r--r--epan/dissectors/packet-snmp.c2
-rw-r--r--epan/dissectors/packet-tdmop.c2
-rw-r--r--epan/dissectors/packet-vines.c2
-rw-r--r--epan/dissectors/packet-zbee-zcl-se.c2
-rw-r--r--epan/dissectors/packet-zbee-zcl.c4
-rw-r--r--epan/prefs.c2
-rw-r--r--epan/uat-int.h2
-rw-r--r--epan/uat.c2
-rw-r--r--epan/uat.h2
-rw-r--r--epan/uat_load.l2
-rwxr-xr-xtools/wireshark_be.py2
-rwxr-xr-xtools/wireshark_gen.py2
-rw-r--r--ui/gtk/uat_gui.c2
-rw-r--r--ui/gtk/uat_gui.h2
38 files changed, 56 insertions, 56 deletions
diff --git a/asn1/atn-cm/packet-atn-cm-template.c b/asn1/atn-cm/packet-atn-cm-template.c
index 4dddf6ef53..070bf61281 100644
--- a/asn1/atn-cm/packet-atn-cm-template.c
+++ b/asn1/atn-cm/packet-atn-cm-template.c
@@ -144,7 +144,7 @@ dissect_atn_cm_heur(
if (is_atn_cm == TRUE) {
/* note: */
/* all subsequent PDU's belonging to this conversation are considered CM */
- /* if the first CM PDU has been decoded succesfully */
+ /* if the first CM PDU has been decoded successfully */
/* (This is done in "atn-ulcs" by using "call_dissector_with_data()") */
/* DT: dstref present, srcref is always zero */
diff --git a/asn1/atn-cpdlc/packet-atn-cpdlc-template.c b/asn1/atn-cpdlc/packet-atn-cpdlc-template.c
index c08071ceb3..870f88cbdf 100644
--- a/asn1/atn-cpdlc/packet-atn-cpdlc-template.c
+++ b/asn1/atn-cpdlc/packet-atn-cpdlc-template.c
@@ -259,7 +259,7 @@ dissect_atn_cpdlc_heur(
/* note: */
/* all subsequent PDU's belonging to this conversation */
/* are considered CPDLC */
- /* if the first CPDLC PDU has been decoded succesfully */
+ /* if the first CPDLC PDU has been decoded successfully */
/* (This is done in "atn-ulcs" by using "call_dissector_with_data()") */
/* DT: dstref present, srcref is always zero */
diff --git a/asn1/snmp/packet-snmp-template.c b/asn1/snmp/packet-snmp-template.c
index ca9e3e4135..1bc8f79fd2 100644
--- a/asn1/snmp/packet-snmp-template.c
+++ b/asn1/snmp/packet-snmp-template.c
@@ -1692,7 +1692,7 @@ snmp_usm_priv_des(snmp_usm_params_t* p _U_, tvbuff_t* encryptedData _U_, gchar c
cryptgrm_len = tvb_captured_length(encryptedData);
if ((cryptgrm_len <= 0) || (cryptgrm_len % 8)) {
- *error = "decryptionError: the length of the encrypted data is not a mutiple of 8 octets";
+ *error = "decryptionError: the length of the encrypted data is not a multiple of 8 octets";
return NULL;
}
diff --git a/epan/dissectors/packet-artnet.c b/epan/dissectors/packet-artnet.c
index 7017d78740..e40688fa32 100644
--- a/epan/dissectors/packet-artnet.c
+++ b/epan/dissectors/packet-artnet.c
@@ -4415,7 +4415,7 @@ proto_register_artnet(void) {
{ "Bind IP Address",
"artnet.poll_reply.bind_ip_address",
FT_IPv4, BASE_NONE, NULL, 0x0,
- "IP adress of root device", HFILL }},
+ "IP address of root device", HFILL }},
{ &hf_artnet_poll_reply_bind_index,
{ "Bind Index",
diff --git a/epan/dissectors/packet-atn-cm.c b/epan/dissectors/packet-atn-cm.c
index 00924be4d5..c82e055f16 100644
--- a/epan/dissectors/packet-atn-cm.c
+++ b/epan/dissectors/packet-atn-cm.c
@@ -717,7 +717,7 @@ dissect_atn_cm_heur(
if (is_atn_cm == TRUE) {
/* note: */
/* all subsequent PDU's belonging to this conversation are considered CM */
- /* if the first CM PDU has been decoded succesfully */
+ /* if the first CM PDU has been decoded successfully */
/* (This is done in "atn-ulcs" by using "call_dissector_with_data()") */
/* DT: dstref present, srcref is always zero */
diff --git a/epan/dissectors/packet-atn-cpdlc.c b/epan/dissectors/packet-atn-cpdlc.c
index 9faf8e50af..ac6115ba9c 100644
--- a/epan/dissectors/packet-atn-cpdlc.c
+++ b/epan/dissectors/packet-atn-cpdlc.c
@@ -5468,7 +5468,7 @@ dissect_atn_cpdlc_heur(
/* note: */
/* all subsequent PDU's belonging to this conversation */
/* are considered CPDLC */
- /* if the first CPDLC PDU has been decoded succesfully */
+ /* if the first CPDLC PDU has been decoded successfully */
/* (This is done in "atn-ulcs" by using "call_dissector_with_data()") */
/* DT: dstref present, srcref is always zero */
diff --git a/epan/dissectors/packet-dcerpc-dce122.c b/epan/dissectors/packet-dcerpc-dce122.c
index 7732a622ba..5f93842b54 100644
--- a/epan/dissectors/packet-dcerpc-dce122.c
+++ b/epan/dissectors/packet-dcerpc-dce122.c
@@ -188,7 +188,7 @@ static const value_string dce_error_vals[] = {
{ 552005634, "Not enough space in buffer passed to routine" },
{ 552005635, "Malformed host name" },
{ 552005636, "failed to disable cancels" },
- { 552005637, "failed to reenable cancels" },
+ { 552005637, "failed to re-enable cancels" },
{ 552005638, "memory allocation failure" },
{ 552005639, "no bindings for this entry" },
{ 552005640, "too many objects in group entry" },
diff --git a/epan/dissectors/packet-dcom.c b/epan/dissectors/packet-dcom.c
index 8ab4fe05d6..57c15c7ffe 100644
--- a/epan/dissectors/packet-dcom.c
+++ b/epan/dissectors/packet-dcom.c
@@ -40,7 +40,7 @@
* windows registry at: "HKEY_CLASSES_ROOT\Interface"
*
*
- * Ressources on the web:
+ * Resources on the web:
*
* "Understanding the DCOM Wire Protocol by Analyzing Network Data Packets"
* http:// www.microsoft.com/msj/0398/dcom.htm
diff --git a/epan/dissectors/packet-devicenet.c b/epan/dissectors/packet-devicenet.c
index d75f662cd2..41651504a0 100644
--- a/epan/dissectors/packet-devicenet.c
+++ b/epan/dissectors/packet-devicenet.c
@@ -599,7 +599,7 @@ static int dissect_devicenet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
break;
default:
expert_add_info_format(pinfo, service_item, &ei_devicenet_invalid_service,
- "Invalid service code (0x%x) for Group 3 Messsage ID 5", service_rr & CIP_SC_MASK);
+ "Invalid service code (0x%x) for Group 3 Message ID 5", service_rr & CIP_SC_MASK);
break;
}
break;
@@ -611,13 +611,13 @@ static int dissect_devicenet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
break;
default:
expert_add_info_format(pinfo, service_item, &ei_devicenet_invalid_service,
- "Invalid service code (0x%x) for Group 3 Messsage ID 6", service_rr & CIP_SC_MASK);
+ "Invalid service code (0x%x) for Group 3 Message ID 6", service_rr & CIP_SC_MASK);
break;
}
break;
case 0x1C0:
expert_add_info_format(pinfo, msg_id_item, &ei_devicenet_invalid_msg_id,
- "Invalid Group 3 Messsage ID (%d)", message_id);
+ "Invalid Group 3 Message ID (%d)", message_id);
break;
}
diff --git a/epan/dissectors/packet-etsi_card_app_toolkit.c b/epan/dissectors/packet-etsi_card_app_toolkit.c
index 7887e8c24a..5007c188f7 100644
--- a/epan/dissectors/packet-etsi_card_app_toolkit.c
+++ b/epan/dissectors/packet-etsi_card_app_toolkit.c
@@ -247,7 +247,7 @@ static const value_string comp_tlv_tag_vals[] = {
{ 0x67, "Frames Information" },
{ 0x68, "Frame identifier" },
{ 0x69, "3GPP UTRAN/E-UTRAN Measurement qualifier" },
- { 0x6a, "Multimedia Messsage Reference" },
+ { 0x6a, "Multimedia Message Reference" },
{ 0x6b, "Multimedia Message Identifier" },
{ 0x6c, "Multimedia Message Transfer Status" },
{ 0x6d, "MEID" },
@@ -615,7 +615,7 @@ static const value_string event_list_vals[] = {
{ 0x0d, "Local connection" },
{ 0x0e, "Network Search Mode Change" },
{ 0x0f, "Browsing status" },
- { 0x10, "Frames Informations Change" },
+ { 0x10, "Frames Information Change" },
{ 0x11, "I-WLAN Access Status" },
{ 0x12, "Network Rejection" },
{ 0x13, "HCI connectivity event" },
diff --git a/epan/dissectors/packet-fmp.c b/epan/dissectors/packet-fmp.c
index 2358eb9367..f3f3eb6843 100644
--- a/epan/dissectors/packet-fmp.c
+++ b/epan/dissectors/packet-fmp.c
@@ -695,7 +695,7 @@ dissect_fmp_Hiervolume(tvbuff_t *tvb, int offset, proto_tree * tree)
volumes and their descriptions may be to large to fit in a single
RPC reply. In this case, the application may send getVolumeInfo
requests for the specific topVolumeId -- specifying the number of
- volumes already recieved by the client, and the cookie. The
+ volumes already received by the client, and the cookie. The
server is then responsible for sending another message containing
additional volumes. These RPCs exchanges may continue multiple
times, until the client has fetched the entire hierarchical
diff --git a/epan/dissectors/packet-gsm_a_common.c b/epan/dissectors/packet-gsm_a_common.c
index 05518d00ed..c78f5ef4a4 100644
--- a/epan/dissectors/packet-gsm_a_common.c
+++ b/epan/dissectors/packet-gsm_a_common.c
@@ -71,7 +71,7 @@ static const value_string gsm_a_skip_ind_vals[] = {
{ 1, "PLMN identity of the Common PLMN in the broadcast system information"},
{ 2, "PLMN identity of the first Additional PLMN in the broadcast system information"},
{ 3, "PLMN identity of the second Additional PLMN in the broadcast system information"},
- { 4, "PLMN identity of the third Additional PLMN in the broadcast sytem information"},
+ { 4, "PLMN identity of the third Additional PLMN in the broadcast system information"},
{ 5, "PLMN identity of the fourth Additional PLMN in the broadcast system information"},
{ 6, "Reserved"},
{ 7, "Reserved"},
diff --git a/epan/dissectors/packet-gsm_rlcmac.c b/epan/dissectors/packet-gsm_rlcmac.c
index c986ecce73..99645ce6ad 100644
--- a/epan/dissectors/packet-gsm_rlcmac.c
+++ b/epan/dissectors/packet-gsm_rlcmac.c
@@ -7738,11 +7738,11 @@ dissect_ul_rlc_control_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tr
ti = proto_tree_add_protocol_format(tree, proto_gsm_rlcmac, tvb, bit_offset >> 3, -1,
"GSM RLC/MAC: %s (%d) (Uplink)",
- val_to_str_ext(data->u.MESSAGE_TYPE, &ul_rlc_message_type_vals_ext, "Unknown Messsage Type"),
+ val_to_str_ext(data->u.MESSAGE_TYPE, &ul_rlc_message_type_vals_ext, "Unknown Message Type"),
data->u.MESSAGE_TYPE);
rlcmac_tree = proto_item_add_subtree(ti, ett_gsm_rlcmac);
- col_append_sep_str(pinfo->cinfo, COL_INFO, ":", val_to_str_ext(data->u.MESSAGE_TYPE, &ul_rlc_message_type_vals_ext, "Unknown Messsage Type"));
+ col_append_sep_str(pinfo->cinfo, COL_INFO, ":", val_to_str_ext(data->u.MESSAGE_TYPE, &ul_rlc_message_type_vals_ext, "Unknown Message Type"));
switch (data->u.MESSAGE_TYPE)
{
@@ -7838,7 +7838,7 @@ dissect_dl_rlc_control_message(tvbuff_t *tvb, packet_info* pinfo, proto_tree *tr
ti = proto_tree_add_protocol_format(tree, proto_gsm_rlcmac, tvb, bit_offset >> 3, -1,
"%s (%d) (downlink)",
- val_to_str_ext(data->u.MESSAGE_TYPE, &dl_rlc_message_type_vals_ext, "Unknown Messsage Type"),
+ val_to_str_ext(data->u.MESSAGE_TYPE, &dl_rlc_message_type_vals_ext, "Unknown Message Type"),
data->u.MESSAGE_TYPE);
rlcmac_tree = proto_item_add_subtree(ti, ett_gsm_rlcmac);
/* Initialize the contexts */
@@ -8063,10 +8063,10 @@ dissect_dl_gprs_block(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, RlcMa
}
data->u.MESSAGE_TYPE = tvb_get_bits8(tvb, message_type_offset, 6);
col_set_str(pinfo->cinfo, COL_PROTOCOL, "GSM RLC/MAC");
- col_append_sep_fstr(pinfo->cinfo, COL_INFO, ":", "GPRS DL:%s", val_to_str_ext(data->u.MESSAGE_TYPE, &dl_rlc_message_type_vals_ext, "Unknown Messsage Type"));
+ col_append_sep_fstr(pinfo->cinfo, COL_INFO, ":", "GPRS DL:%s", val_to_str_ext(data->u.MESSAGE_TYPE, &dl_rlc_message_type_vals_ext, "Unknown Message Type"));
ti = proto_tree_add_protocol_format(tree, proto_gsm_rlcmac, tvb, message_type_offset >> 3, -1,
"GSM RLC/MAC: %s (%d) (Downlink)",
- val_to_str_ext(data->u.MESSAGE_TYPE, &dl_rlc_message_type_vals_ext, "Unknown Messsage Type"),
+ val_to_str_ext(data->u.MESSAGE_TYPE, &dl_rlc_message_type_vals_ext, "Unknown Message Type"),
data->u.MESSAGE_TYPE);
rlcmac_tree = proto_item_add_subtree(ti, ett_gsm_rlcmac);
diff --git a/epan/dissectors/packet-icep.c b/epan/dissectors/packet-icep.c
index 22c35b5141..9ed9cd8b93 100644
--- a/epan/dissectors/packet-icep.c
+++ b/epan/dissectors/packet-icep.c
@@ -33,7 +33,7 @@
NOTES:
1) p. 586 Chapter 23.2 of "The ICE Protocol"
"Data is always encoded using little-endian byte order for numeric types."
- 2) Informations about Ice can be found here: http://www.zeroc.com
+ 2) Information about Ice can be found here: http://www.zeroc.com
*/
#include "config.h"
diff --git a/epan/dissectors/packet-lg8979.c b/epan/dissectors/packet-lg8979.c
index a0bf807a67..cbc9412e46 100644
--- a/epan/dissectors/packet-lg8979.c
+++ b/epan/dissectors/packet-lg8979.c
@@ -888,7 +888,7 @@ dissect_lg8979(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _
offset += 3;
- /* Retreive the +90% reference */
+ /* Retrieve the +90% reference */
ana12_val = ( tvb_get_guint8(tvb, offset) | ((tvb_get_guint8(tvb, offset+1) & 0x0F) << 8) );
proto_tree_add_uint(lg8979_tree, hf_lg8979_adc_ref_pos90, tvb, offset, 2, ana12_val);
offset += 2;
diff --git a/epan/dissectors/packet-ncp2222.inc b/epan/dissectors/packet-ncp2222.inc
index 8d65fac845..205cb9f723 100644
--- a/epan/dissectors/packet-ncp2222.inc
+++ b/epan/dissectors/packet-ncp2222.inc
@@ -1158,7 +1158,7 @@ static const value_string nds_reply_errors[] = {
{ 0xffffff0a, "(-246) No Property Delete Rights" },
{ 0xffffff09, "(-247) No Property Create Rights" },
{ 0xffffff08, "(-248) No Property Write Rights" },
- { 0xffffff07, "(-249) No Propery Read Rights" },
+ { 0xffffff07, "(-249) No Property Read Rights" },
{ 0xffffff06, "(-250) Temp Remap" },
{ 0xffffff05, "(-251) Unknown Request/No Such Property" },
{ 0xffffff04, "(-252) Message Queue Full/Target Already Has Message/No Such Object" },
diff --git a/epan/dissectors/packet-nstrace.c b/epan/dissectors/packet-nstrace.c
index d7a2089bd2..88b373a9ed 100644
--- a/epan/dissectors/packet-nstrace.c
+++ b/epan/dissectors/packet-nstrace.c
@@ -375,8 +375,8 @@ static const value_string ns_httpabortcode_vals[] = {
{4, "VPN GSLB CONNECTION PROXY connections"},
{5, "if http FA moves to unknown on clt req; svr_pcb's http state is also made unknown"},
{6, "Incomplete HTTP chunk"},
- {7, "forward proxy connect url recieved and flagged for noreuse"},
- {8, "connection is not reused because we recieved more than content-length amount of data from server"},
+ {7, "forward proxy connect url received and flagged for noreuse"},
+ {8, "connection is not reused because we received more than content-length amount of data from server"},
{9, "the Incomplete header reassembly failed"},
{10, "invalid header"},
{11, "RTSP : the Incomplete header reassembly failed"},
diff --git a/epan/dissectors/packet-pathport.c b/epan/dissectors/packet-pathport.c
index bfbeab1e53..c44157063e 100644
--- a/epan/dissectors/packet-pathport.c
+++ b/epan/dissectors/packet-pathport.c
@@ -301,7 +301,7 @@ static const value_string pp_pid_vals[] = {
{PP_PORT_ACTIVE_SUMMARY, "Port Active Bitmap"},
{PP_SUPPORTED_UNIV, "Number Supported Univ"},
{PP_INPUT_HLL_TIME, "Signal Loss Hold Time (DMX IN)"},
- {PP_PCP_ENABLE, "Per Channel Priorty Enable"},
+ {PP_PCP_ENABLE, "Per Channel Priority Enable"},
{PP_INPUT_UNIVERSE, "Input Universe"},
{PP_MODEL_NAME, "Model Name"},
{PP_MANUF_NAME, "Manufacturer Name"},
diff --git a/epan/dissectors/packet-pnrp.c b/epan/dissectors/packet-pnrp.c
index 5bacbef998..46443a7637 100644
--- a/epan/dissectors/packet-pnrp.c
+++ b/epan/dissectors/packet-pnrp.c
@@ -447,7 +447,7 @@ static int dissect_pnrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
message_type = tvb_get_guint8(tvb,7);
- /* Simply Display the Protcol Name in the INFO column */
+ /* Simply Display the Protocol Name in the INFO column */
col_set_str(pinfo->cinfo, COL_PROTOCOL, "PNRP");
/* Clear out stuff in the info column */
col_add_fstr(pinfo->cinfo, COL_INFO, "PNRP %s Message ",
diff --git a/epan/dissectors/packet-s7comm.c b/epan/dissectors/packet-s7comm.c
index 3378ada3a5..ed550567fa 100644
--- a/epan/dissectors/packet-s7comm.c
+++ b/epan/dissectors/packet-s7comm.c
@@ -158,8 +158,8 @@ static const value_string param_errcode_names[] = {
{ S7COMM_PERRCOD_NO_ERROR, "No error" },
{ S7COMM_PERRCOD_INVALID_BLOCK_TYPE_NUM, "Invalid block type number" },
{ S7COMM_PERRCOD_INVALID_PARAM, "Invalid parameter" },
- { S7COMM_PERRCOD_PG_RESOURCE_ERROR, "PG ressource error" },
- { S7COMM_PERRCOD_PLC_RESOURCE_ERROR, "PLC ressource error" },
+ { S7COMM_PERRCOD_PG_RESOURCE_ERROR, "PG resource error" },
+ { S7COMM_PERRCOD_PLC_RESOURCE_ERROR, "PLC resource error" },
{ S7COMM_PERRCOD_PROTOCOL_ERROR, "Protocol error" },
{ S7COMM_PERRCOD_USER_BUFFER_TOO_SHORT, "User buffer too short" },
{ S7COMM_PERRCOD_REQ_INI_ERR, "Request error" },
diff --git a/epan/dissectors/packet-sflow.c b/epan/dissectors/packet-sflow.c
index bcbfc93571..05ac3a166a 100644
--- a/epan/dissectors/packet-sflow.c
+++ b/epan/dissectors/packet-sflow.c
@@ -1371,7 +1371,7 @@ dissect_sflow_5_extended_80211_tx(tvbuff_t *tvb, proto_tree *tree, gint offset)
break;
case 1:
proto_tree_add_uint_format_value(tree, hf_sflow_5_extended_80211_tx_retransmissions, tvb, offset, 4,
- 1, "Packet transmitted sucessfully on first attempt");
+ 1, "Packet transmitted successfully on first attempt");
break;
default:
proto_tree_add_uint(tree, hf_sflow_5_extended_80211_tx_retransmissions, tvb, offset, 4, transmissions - 1);
diff --git a/epan/dissectors/packet-smb2.c b/epan/dissectors/packet-smb2.c
index ec5faa8a05..01ed066df1 100644
--- a/epan/dissectors/packet-smb2.c
+++ b/epan/dissectors/packet-smb2.c
@@ -8239,7 +8239,7 @@ proto_register_smb2(void)
&NT_errors_ext, 0, "NT Status code", HFILL }},
{ &hf_smb2_msg_id,
{ "Message ID", "smb2.msg_id", FT_INT64, BASE_DEC,
- NULL, 0, "SMB2 Messsage ID", HFILL }},
+ NULL, 0, "SMB2 Message ID", HFILL }},
{ &hf_smb2_tid,
{ "Tree Id", "smb2.tid", FT_UINT32, BASE_HEX,
NULL, 0, "SMB2 Tree Id", HFILL }},
diff --git a/epan/dissectors/packet-smcr.c b/epan/dissectors/packet-smcr.c
index 0abef03b74..ef11b04f60 100644
--- a/epan/dissectors/packet-smcr.c
+++ b/epan/dissectors/packet-smcr.c
@@ -1067,7 +1067,7 @@ proto_register_smcr(void)
FT_UINT32, BASE_HEX, NULL, 0x0, NULL, HFILL}},
{ &hf_smcr_accept_server_rmb_virtual_address, {
- "Server's RMB Vitual Address",
+ "Server's RMB Virtual Address",
"smcr.accept.server.rmb.virtual.address",
FT_UINT64, BASE_HEX, NULL, 0x0, NULL, HFILL}},
@@ -1107,7 +1107,7 @@ proto_register_smcr(void)
FT_UINT32, BASE_HEX, NULL, 0x0, NULL, HFILL}},
{ &hf_smcr_confirm_client_rmb_virtual_address, {
- "Client's RMB Vitual Address",
+ "Client's RMB Virtual Address",
"smcr.client.rmb.virtual.address",
FT_UINT64, BASE_HEX, NULL, 0x0, NULL, HFILL}},
diff --git a/epan/dissectors/packet-snmp.c b/epan/dissectors/packet-snmp.c
index 2556c9b3c0..4b7ffadc0b 100644
--- a/epan/dissectors/packet-snmp.c
+++ b/epan/dissectors/packet-snmp.c
@@ -1794,7 +1794,7 @@ snmp_usm_priv_des(snmp_usm_params_t* p _U_, tvbuff_t* encryptedData _U_, gchar c
cryptgrm_len = tvb_captured_length(encryptedData);
if ((cryptgrm_len <= 0) || (cryptgrm_len % 8)) {
- *error = "decryptionError: the length of the encrypted data is not a mutiple of 8 octets";
+ *error = "decryptionError: the length of the encrypted data is not a multiple of 8 octets";
return NULL;
}
diff --git a/epan/dissectors/packet-tdmop.c b/epan/dissectors/packet-tdmop.c
index 196586f0da..15cf7fcf47 100644
--- a/epan/dissectors/packet-tdmop.c
+++ b/epan/dissectors/packet-tdmop.c
@@ -251,7 +251,7 @@ void proto_register_tdmop(void)
},
{
&hf_tdmop_Flags_remote_no_data,
- { "TDMoP No data recieved from remote side flag", "tdmop.flags.remotenodata",
+ { "TDMoP No data received from remote side flag", "tdmop.flags.remotenodata",
FT_BOOLEAN, 8,
NULL, TDMOP_FLAG_REMOTE_NO_DATA,
NULL, HFILL}
diff --git a/epan/dissectors/packet-vines.c b/epan/dissectors/packet-vines.c
index 1cdd3abe15..ecc494c6ec 100644
--- a/epan/dissectors/packet-vines.c
+++ b/epan/dissectors/packet-vines.c
@@ -267,7 +267,7 @@ static gint ett_vines_icp = -1;
enum {
VIP_PROTO_IPC = 1, /* Interprocess Communications Protocol (IPC) */
- VIP_PROTO_SPP = 2, /* Sequenced Packet Protcol (SPP) */
+ VIP_PROTO_SPP = 2, /* Sequenced Packet Protocol (SPP) */
VIP_PROTO_ARP = 4, /* Address Resolution Protocol (ARP) */
VIP_PROTO_RTP = 5, /* Routing Update Protocol (RTP) / SRTP (Sequenced RTP) */
VIP_PROTO_ICP = 6 /* Internet Control Protocol (ICP) */
diff --git a/epan/dissectors/packet-zbee-zcl-se.c b/epan/dissectors/packet-zbee-zcl-se.c
index 43ad050686..34d91460b4 100644
--- a/epan/dissectors/packet-zbee-zcl-se.c
+++ b/epan/dissectors/packet-zbee-zcl-se.c
@@ -1170,7 +1170,7 @@ dissect_zcl_tun_get_supported_rsp(tvbuff_t *tvb, proto_tree *tree, guint *offset
while (tvb_reported_length_remaining(tvb, *offset) > 0) {
mfg_code = tvb_get_letohs(tvb, *offset);
if (mfg_code == 0xFFFF) {
- proto_tree_add_string(tree, hf_zbee_zcl_tun_manufacturer_code, tvb, *offset, 2, "Standard Protcol (Mfg Code 0xFFFF)");
+ proto_tree_add_string(tree, hf_zbee_zcl_tun_manufacturer_code, tvb, *offset, 2, "Standard Protocol (Mfg Code 0xFFFF)");
}
else {
proto_tree_add_item(tree, hf_zbee_zcl_tun_manufacturer_code, tvb, *offset, 2, ENC_LITTLE_ENDIAN);
diff --git a/epan/dissectors/packet-zbee-zcl.c b/epan/dissectors/packet-zbee-zcl.c
index 083b90ad3a..f5fdcf849d 100644
--- a/epan/dissectors/packet-zbee-zcl.c
+++ b/epan/dissectors/packet-zbee-zcl.c
@@ -1342,8 +1342,8 @@ static void dissect_zcl_default_resp(tvbuff_t *tvb, packet_info *pinfo _U_, prot
zbee_zcl_cluster_desc *desc;
int hf_cmd_id = hf_zbee_zcl_cs_cmd_id;
- /* Retreive the cluster-specific command ID definition, with the direction
- * inverted, since this a response to the originating command. */
+ /* Retrieve the cluster-specific command ID definition, with the direction
+ * inverted, since this is a response to the originating command. */
desc = zbee_zcl_get_cluster_desc(cluster_id);
if (dir == ZBEE_ZCL_FCF_TO_SERVER) {
if (desc && (desc->hf_cmd_tx_id >= 0)) hf_cmd_id = desc->hf_cmd_tx_id;
diff --git a/epan/prefs.c b/epan/prefs.c
index 4dd4e54244..0159bcbd95 100644
--- a/epan/prefs.c
+++ b/epan/prefs.c
@@ -4535,7 +4535,7 @@ prefs_pref_type_name(pref_t *pref)
char *
prefs_pref_type_description(pref_t *pref)
{
- const char *type_desc = "An unkown preference type";
+ const char *type_desc = "An unknown preference type";
if (!pref) {
return g_strdup_printf("%s.", type_desc); /* ...or maybe assert? */
diff --git a/epan/uat-int.h b/epan/uat-int.h
index c1b488ba99..46a32bcf9a 100644
--- a/epan/uat-int.h
+++ b/epan/uat-int.h
@@ -2,7 +2,7 @@
* uat-int.h
*
* User Accessible Tables
- * Mantain an array of user accessible data strucures
+ * Maintain an array of user accessible data structures
* Internal interface
*
* (c) 2007, Luis E. Garcia Ontanon <luis@ontanon.org>
diff --git a/epan/uat.c b/epan/uat.c
index 327b8a29bd..0301d0cde5 100644
--- a/epan/uat.c
+++ b/epan/uat.c
@@ -2,7 +2,7 @@
* uat.c
*
* User Accessible Tables
- * Mantain an array of user accessible data strucures
+ * Maintain an array of user accessible data structures
*
* (c) 2007, Luis E. Garcia Ontanon <luis@ontanon.org>
*
diff --git a/epan/uat.h b/epan/uat.h
index 3a87ca85ee..eae0c6366d 100644
--- a/epan/uat.h
+++ b/epan/uat.h
@@ -2,7 +2,7 @@
* uat.h
*
* User Accessible Tables
- * Mantain an array of user accessible data strucures
+ * Maintain an array of user accessible data strucures
*
* (c) 2007, Luis E. Garcia Ontanon <luis@ontanon.org>
*
diff --git a/epan/uat_load.l b/epan/uat_load.l
index 0f1ef93536..149c03226b 100644
--- a/epan/uat_load.l
+++ b/epan/uat_load.l
@@ -29,7 +29,7 @@
* uat_load.l
*
* User Accessible Tables
- * Mantain an array of user accessible data strucures
+ * Maintain an array of user accessible data strucures
* One parser to fit them all
*
* (c) 2007, Luis E. Garcia Ontanon <luis@ontanon.org>
diff --git a/tools/wireshark_be.py b/tools/wireshark_be.py
index 44ffa63a62..ec63ed1a7f 100755
--- a/tools/wireshark_be.py
+++ b/tools/wireshark_be.py
@@ -48,7 +48,7 @@
# generator (wireshark_gen) class and let it do the hard work !
#
#
-# Dont forget structs can contain embedded structs etc .. so dont forget
+# Don't forget structs can contain embedded structs etc .. so don't forget
# to peek inside and check :-)
#
#
diff --git a/tools/wireshark_gen.py b/tools/wireshark_gen.py
index f1f6e28cd5..250a434791 100755
--- a/tools/wireshark_gen.py
+++ b/tools/wireshark_gen.py
@@ -91,7 +91,7 @@ import tempfile
#
# 12. Implement IDL "union" code [done]
# 13. Implement support for plugins [done]
-# 14. Dont generate code for empty operations (cf: exceptions without members)
+# 14. Don't generate code for empty operations (cf: exceptions without members)
# 15. Generate code to display Enums numerically and symbolically [done]
# 16. Place structs/unions in subtrees
# 17. Recursive struct and union handling [done]
diff --git a/ui/gtk/uat_gui.c b/ui/gtk/uat_gui.c
index e4de9ffe7d..fa770fa6b1 100644
--- a/ui/gtk/uat_gui.c
+++ b/ui/gtk/uat_gui.c
@@ -2,7 +2,7 @@
* uat_gui.c
*
* User Accessible Tables GUI
- * Mantain an array of user accessible data strucures
+ * Maintain an array of user accessible data strucures
*
* (c) 2007, Luis E. Garcia Ontanon <luis@ontanon.org>
*
diff --git a/ui/gtk/uat_gui.h b/ui/gtk/uat_gui.h
index 269a1bda49..a3ac241c8f 100644
--- a/ui/gtk/uat_gui.h
+++ b/ui/gtk/uat_gui.h
@@ -2,7 +2,7 @@
* uat_gui.h
*
* User Accessible Tables GUI
- * Mantain an array of user accessible data strucures
+ * Maintain an array of user accessible data strucures
*
* (c) 2007, Luis E. Garcia Ontanon <luis@ontanon.org>
*
diff --git a/epan/dissectors/packet-mausb.c b/epan/dissectors/packet-mausb.c
index d006148fc2..b060446ee1 100644
--- a/epan/dissectors/packet-mausb.c
+++ b/epan/dissectors/packet-mausb.c
@@ -61,7 +61,7 @@ static int hf_mausb_ma_dev_addr = -1;
static int hf_mausb_ssid = -1;
static int hf_mausb_status = -1;
/* managment packet specific */
static int hf_mausb_token = -1;
static int hf_mausb_mgmt_pad = -1;
static int hf_mausb_mgmt_ep_handle_num = -1;
@@ -1232,7 +1232,7 @@ static guint16 dissect_mausb_mgmt_pkt_flds(struct mausb_header *header,
offset, FALSE, FALSE);
break;
/* TODO: Dissect type-specific managment packet fields */
case EPActivateReq:
case EPActivateResp:
case EPInactivateReq:
@@ -1346,7 +1346,7 @@ static conversation_t
conversation = get_usb_conversation(pinfo, &pinfo->src, &pinfo->dst,
pinfo->srcport, pinfo->destport);
}
/* TODO: track control & managment packet conversations */
return conversation;
}
@@ -1789,12 +1789,12 @@ proto_register_mausb(void)
}
},
{ &hf_mausb_mgmt_type_spec,
- { "Type-specific managment packet fields", "mausb.mgmt_flds",
+ { "Type-specific management packet fields", "mausb.mgmt_flds",
FT_NONE, 0, NULL, 0, NULL, HFILL
}
},
{ &hf_mausb_mgmt_type_spec_generic,
- { "Type-specific managment packet fields", "mausb.mgmt_flds.generic",
+ { "Type-specific management packet fields", "mausb.mgmt_flds.generic",
FT_NONE, 0, NULL, 0, NULL, HFILL
}
},
@@ -2178,15 +2178,15 @@ proto_register_mausb(void)
},
{ &ei_mgmt_type_undef,
{ "mausb.ei.type", PI_PROTOCOL, PI_WARN,
- "Undefined managment packet type", EXPFILL }
+ "Undefined management packet type", EXPFILL }
},
{ &ei_mgmt_type_spec_len_long,
{ "mausb.ei.type_spec.len", PI_PROTOCOL, PI_WARN,
- "Data exists after type-specific managment packet field", EXPFILL }
+ "Data exists after type-specific management packet field", EXPFILL }
},
{ &ei_mgmt_type_spec_len_short,
{ "mausb.ei.type_spec.len", PI_PROTOCOL, PI_WARN,
- "Expected type-specific managment packet data", EXPFILL }
+ "Expected type-specific management packet data", EXPFILL }
},
{ &ei_dev_cap_len,
{ "mausb.ei.cap_resp.dev_cap.length", PI_PROTOCOL, PI_WARN,
@@ -61,7 +61,7 @@ static int hf_mausb_ma_dev_addr = -1;
static int hf_mausb_ssid = -1;
static int hf_mausb_status = -1;
-/* managment packet specific */
+/* management packet specific */
static int hf_mausb_token = -1;
static int hf_mausb_mgmt_pad = -1;
@@ -1232,7 +1232,7 @@ static guint16 dissect_mausb_mgmt_pkt_flds(struct mausb_header *header,
offset, FALSE, FALSE);
break;
- /* TODO: Dissect type-specific managment packet fields */
+ /* TODO: Dissect type-specific management packet fields */
case EPActivateReq:
case EPActivateResp:
@@ -1346,7 +1346,7 @@ static conversation_t
pinfo->srcport, pinfo->destport);
}
- /* TODO: track control & managment packet conversations */
+ /* TODO: track control & management packet conversations */
return conversation;
}